# eric7.WebBrowser.StatusBar.JavaScriptIcon

Module implementing the JavaScript status bar icon.

### Global Attributes

None

### Classes

JavaScriptIcon | Class implementing the JavaScript status bar icon.

### Functions

None

## JavaScriptIcon

Class implementing the JavaScript status bar icon.

### Derived from

StatusBarIcon

### Class Attributes

None

### Class Methods

None

### Methods

JavaScriptIcon | Constructor
__navigationRequestAccepted | Private method to handle the navigationRequestAccepted signal.
__showJavaScriptSettingsDialog | Private slot to show the JavaScript settings dialog.
__showMenu | Private slot to show the menu.
__toggleJavaScript | Private slot to toggle the JavaScript setting.
__updateIcon | Private slot to update the icon.
preferencesChanged | Public method to handle changes of the settings.

### Static Methods

None

#### JavaScriptIcon (Constructor)

JavaScriptIcon(window)

Constructor

window (WebBrowserWindow)
  reference to the web browser window

#### JavaScriptIcon.__navigationRequestAccepted

__navigationRequestAccepted(url, navigationType, isMainFrame, page)

Private method to handle the navigationRequestAccepted signal.

url (QUrl)
  URL being loaded
navigationType (QWebEnginePage.NavigationType)
  type of navigation request
isMainFrame (bool)
  flag indicating a navigation request of the main frame
page (WebBrowserPage)
  reference to the web page

#### JavaScriptIcon.__showJavaScriptSettingsDialog

__showJavaScriptSettingsDialog()

Private slot to show the JavaScript settings dialog.

Note: This is the JavaScript subset of the web browser configuration page.

#### JavaScriptIcon.__showMenu

__showMenu(pos)

Private slot to show the menu.

pos (QPoint)
  position to show the menu at

#### JavaScriptIcon.__toggleJavaScript

__toggleJavaScript()

Private slot to toggle the JavaScript setting.

#### JavaScriptIcon.__updateIcon

__updateIcon()

Private slot to update the icon.

#### JavaScriptIcon.preferencesChanged

preferencesChanged()

Public method to handle changes of the settings.

Up